@@ -3,10 +3,10 @@
 # license that can be found in the LICENSE file.
 
 from unittest import TestCase
-from mock import Mock, patch
+from mock import Mock
 import os.path
 
-from tsuru.plugins import ProcfileWatcher, WatcherCreationError
+from tsuru.plugins import ProcfileWatcher, WatcherCreationError, FileWatcher
 
 from honcho.procfile import Procfile
 
@@ -29,27 +29,12 @@ class ProcfileWatcherTest(TestCase):
             "gid": "ubuntu",
         }
 
-    def test_handle_recv(self):
+    def test_periodic_callback(self):
         plugin = ProcfileWatcher("", "", 1)
-        plugin.reload_procfile = Mock()
-        plugin.handle_recv(None)
-        plugin.reload_procfile.assert_called_once()
 
-    @patch("time.sleep")
-    def test_handle_recv_retries(self, sleep):
-        calls = {"c": 0}
-
-        def reload():
-            calls["c"] += 1
-            if calls["c"] == 1:
-                raise WatcherCreationError()
-        mock = Mock()
-        mock.side_effect = reload
-        plugin = ProcfileWatcher("", "", 1)
-        plugin.reload_procfile = mock
-        plugin.handle_recv(None)
-        plugin.reload_procfile.assert_called()
-        sleep.assert_called_once_with(1)
+        self.assertEqual(3000, plugin.period.callback_time)
+        self.assertIsInstance(plugin.period.callback, FileWatcher)
+        self.assertEqual(plugin.period.callback._callback, plugin.reload_procfile)
 
     def test_add_watcher(self):
         plugin = ProcfileWatcher("", "", 1)
