@@ -1,3 +1,7 @@
+# Copyright 2014 tsuru-circus authors. All rights reserved.
+# Use of this source code is governed by a BSD-style
+# license that can be found in the LICENSE file.
+
 import os
 import unittest
 
@@ -16,7 +20,8 @@ class CommonTestCase(unittest.TestCase):
             "TSURU_SYSLOG_SERVER": "host2",
             "TSURU_SYSLOG_PORT": "514",
             "TSURU_SYSLOG_FACILITY": "LOCAL0",
-            "BASE64_STRING": "t5urur0ck5=="
+            "BASE64_STRING": "t5urur0ck5==",
+            "DOCKER_HOSTS": '["10.10.10.10", "10.10.10.1"]',
         }
         got = common.load_envs(path)
         self.assertEqual(want, got)
